==> openGion7.0.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA03S.sql <==
/****************************************************************************/
/* GEA03 ( ｶﾗﾑ定義 )                                                        */
/*                                                                          */
/* Created : 2018/09/28 16:03:40                                            */
/****************************************************************************/

CREATE TABLE GEA03 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , NAME_JA          varchar           (  200 )                                      /*  30 名称         */
 , CLS_NAME         varchar           (   10 )                                      /*  40 DBｸﾗｽ        */
 , USE_LENGTH       varchar           (    9 )      DEFAULT '0' NOT NULL            /*  50 使用桁数     */
 , VIEW_LENGTH      varchar           (   10 )                                      /*  60 表示桁数     */
 , RENDERER         varchar           (   10 )                                      /*  70 表示種別     */
 , EDITOR           varchar           (   10 )                                      /*  80 編集種別     */
 , DBTYPE           varchar           (   10 )                                      /*  90 文字種別     */
 , DATA_DEFAULT     varchar           (   30 )                                      /* 100 初期値       */
 , LABEL_CLM        varchar           (   30 )                                      /* 110 ﾗﾍﾞﾙｶﾗﾑ      */
 , CODE_CLM         varchar           (   30 )                                      /* 120 ｺｰﾄﾞｶﾗﾑ      */
 , RENDERER_PARAM   varchar           (  200 )                                      /* 130 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     varchar           (  200 )                                      /* 140 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       varchar           (  200 )                                      /* 150 文字ﾊﾟﾗﾒｰﾀ   */
 , COMMENTS         varchar           (  500 )                                      /* 160 ｺﾒﾝﾄ         */
 , CDKH             varchar           (    1 )                                      /* 170 改廃ｺｰﾄﾞ     */
 , FGLOAD           varchar           (    1 )      DEFAULT '0' NOT NULL            /* 180 読込F        */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /* 190 作成区分     */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 200 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar           (   20 )                                      /* 210 設変番号     */
 , ROLES            varchar           ( 2000 )                                      /* 220 ﾛｰﾙｽﾞ        */
 , CLM_PARAM        varchar           (  200 )                                      /* 230 ｶﾗﾑﾊﾟﾗﾒｰﾀ    */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 登録日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);

==> openGion7.4.0.0_dev.zip: uap/webapps/ge/db/SQLSERVER/sql/install/01_TABLE/GEA03S.sql <==
/****************************************************************************/
/* GEA03 ( ｶﾗﾑ定義 )                                                        */
/*                                                                          */
/* Created : 2020/12/16 08:14:20                                            */
/****************************************************************************/

CREATE TABLE GEA03 (
   SYSTEM_ID        varchar           (   10 )                  NOT NULL            /*  10 ｼｽﾃﾑID       */
 , CLM              varchar           (   30 )                  NOT NULL            /*  20 項目         */
 , NAME_JA          varchar           (  200 )                                      /*  30 名称         */
 , CLS_NAME         varchar           (   10 )                                      /*  40 DBｸﾗｽ        */
 , USE_LENGTH       varchar           (    9 )      DEFAULT '0' NOT NULL            /*  50 使用桁数     */
 , VIEW_LENGTH      varchar           (   10 )                                      /*  60 表示桁数     */
 , RENDERER         varchar           (   10 )                                      /*  70 表示種別     */
 , EDITOR           varchar           (   10 )                                      /*  80 編集種別     */
 , DBTYPE           varchar           (   10 )                                      /*  90 文字種別     */
 , DATA_DEFAULT     varchar           (   30 )                                      /* 100 初期値       */
 , LABEL_CLM        varchar           (   30 )                                      /* 110 ﾗﾍﾞﾙｶﾗﾑ      */
 , CODE_CLM         varchar           (   30 )                                      /* 120 ｺｰﾄﾞｶﾗﾑ      */
 , RENDERER_PARAM   varchar           (  500 )                                      /* 130 表示ﾊﾟﾗﾒｰﾀ   */
 , EDITOR_PARAM     varchar           (  500 )                                      /* 140 編集ﾊﾟﾗﾒｰﾀ   */
 , TYPE_PARAM       varchar           (  200 )                                      /* 150 文字ﾊﾟﾗﾒｰﾀ   */
 , COMMENTS         varchar           (  500 )                                      /* 160 ｺﾒﾝﾄ         */
 , CDKH             varchar           (    1 )                                      /* 170 改廃ｺｰﾄﾞ     */
 , FGLOAD           varchar           (    1 )      DEFAULT '0' NOT NULL            /* 180 読込F        */
 , KBSAKU           varchar           (    1 )      DEFAULT '1' NOT NULL            /* 190 作成区分     */
 , RELEASE_NOTES    varchar           (  120 )                                      /* 200 ﾘﾘｰｽﾉｰﾄ      */
 , RDC_CODE         varchar           (   20 )                                      /* 210 設変番号     */
 , ROLES            varchar           ( 2000 )                                      /* 220 ﾛｰﾙｽﾞ        */
 , CLM_PARAM        varchar           (  200 )                                      /* 230 ｶﾗﾑﾊﾟﾗﾒｰﾀ    */
 , UNIQ             int IDENTITY(1,1)                                               /* 800 ﾕﾆｰｸｷｰ       */
 , FGJ              varchar           (    1 )      DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ     */
 , DYSET            varchar           (   14 )                                      /* 820 作成日時     */
 , PGSET            varchar           (   10 )                                      /* 830 作成PG       */
 , PGPSET           varchar           (   10 )                                      /* 840 作成親PG     */
 , USRSET           varchar           (   10 )                                      /* 850 作成者       */
 , DYUPD            varchar           (   14 )                                      /* 860 更新日時     */
 , PGUPD            varchar           (   10 )                                      /* 870 更新PG       */
 , PGPUPD           varchar           (   10 )                                      /* 880 更新親PG     */
 , USRUPD           varchar           (   10 )                                      /* 890 更新者       */
);
